EXPORTS
	?LocateResourceFile@ESMRHelper@@SAHABVTDesC16@@0AAV?$TBuf@$0BAA@@@PAVRFs@@@Z @ 1 NONAME ; int ESMRHelper::LocateResourceFile(class TDesC16 const &, class TDesC16 const &, class TBuf<256> &, class RFs *)
	?FeatureSupported@CESMRFeatureSettings@@QBEHI@Z @ 2 NONAME ; int CESMRFeatureSettings::FeatureSupported(unsigned int) const
	?PhoneOwnerAddrL@ESMREntryHelper@@SAABVTDesC16@@ABVCCalEntry@@AAVCMRMailboxUtils@@@Z @ 3 NONAME ; class TDesC16 const & ESMREntryHelper::PhoneOwnerAddrL(class CCalEntry const &, class CMRMailboxUtils &)
	?OccursInPastL@ESMREntryHelper@@SAHABVCCalEntry@@@Z @ 4 NONAME ; int ESMREntryHelper::OccursInPastL(class CCalEntry const &)
	?PopulateChildFromParentL@ESMRHelper@@SAXAAVCCalEntry@@ABV2@@Z @ 5 NONAME ; void ESMRHelper::PopulateChildFromParentL(class CCalEntry &, class CCalEntry const &)
	?IsModifyingEntryL@ESMREntryHelper@@SAHABVCCalEntry@@@Z @ 6 NONAME ; int ESMREntryHelper::IsModifyingEntryL(class CCalEntry const &)
	?CopyUserL@ESMRHelper@@SAPAVCCalUser@@AAV2@@Z @ 7 NONAME ; class CCalUser * ESMRHelper::CopyUserL(class CCalUser &)
	?SetInstanceStartAndEndL@ESMREntryHelper@@SAXAAVCCalEntry@@ABV2@ABVTCalTime@@@Z @ 8 NONAME ; void ESMREntryHelper::SetInstanceStartAndEndL(class CCalEntry &, class CCalEntry const &, class TCalTime const &)
	?IsCancelledL@ESMREntryHelper@@SAHABVCCalEntry@@AAVCMRMailboxUtils@@@Z @ 9 NONAME ; int ESMREntryHelper::IsCancelledL(class CCalEntry const &, class CMRMailboxUtils &)
	?CopyAttendeeL@ESMRHelper@@SAPAVCCalAttendee@@AAV2@@Z @ 10 NONAME ; class CCalAttendee * ESMRHelper::CopyAttendeeL(class CCalAttendee &)
	?LoadResourceL@ESMRHelper@@SAHABVTDesC16@@0@Z @ 11 NONAME ; int ESMRHelper::LoadResourceL(class TDesC16 const &, class TDesC16 const &)
	?AddressWithoutMailtoPrefix@ESMRHelper@@SA?AVTPtrC16@@ABVTDesC16@@@Z @ 12 NONAME ; class TPtrC16 ESMRHelper::AddressWithoutMailtoPrefix(class TDesC16 const &)
	?IsLatestSavedSentL@ESMREntryHelper@@SAHABVCCalEntry@@@Z @ 13 NONAME ; int ESMREntryHelper::IsLatestSavedSentL(class CCalEntry const &)
	?CopyEntryL@ESMRHelper@@SAPAVCCalEntry@@ABV2@W4TMethod@2@W4TCopyFields@1@W4TESMRCalendarEventType@@@Z @ 14 NONAME ; class CCalEntry * ESMRHelper::CopyEntryL(class CCalEntry const &, enum CCalEntry::TMethod, enum ESMRHelper::TCopyFields, enum TESMRCalendarEventType)
	?EqualAttendeeL@ESMREntryHelper@@SAPAVCCalAttendee@@ABV2@ABVCCalEntry@@@Z @ 15 NONAME ; class CCalAttendee * ESMREntryHelper::EqualAttendeeL(class CCalAttendee const &, class CCalEntry const &)
	?EventTypeL@ESMREntryHelper@@SA?AW4TESMRCalendarEventType@@ABVCCalEntry@@@Z @ 16 NONAME ; enum TESMRCalendarEventType ESMREntryHelper::EventTypeL(class CCalEntry const &)
	?CopyAttendeeLC@ESMRHelper@@SAPAVCCalAttendee@@AAV2@@Z @ 17 NONAME ; class CCalAttendee * ESMRHelper::CopyAttendeeLC(class CCalAttendee &)
	?CreateAndAppendPrivateDirToFileName@ESMRHelper@@SAHAAV?$TBuf@$0BAA@@@@Z @ 18 NONAME ; int ESMRHelper::CreateAndAppendPrivateDirToFileName(class TBuf<256> &)
	?SpansManyDaysL@ESMREntryHelper@@SAHABVTCalTime@@0@Z @ 19 NONAME ; int ESMREntryHelper::SpansManyDaysL(class TCalTime const &, class TCalTime const &)
	?CheckRepeatUntilValidityL@ESMREntryHelper@@SAXAAVCCalEntry@@ABVTCalTime@@@Z @ 20 NONAME ; void ESMREntryHelper::CheckRepeatUntilValidityL(class CCalEntry &, class TCalTime const &)
	?CopyFieldsL@ESMRHelper@@SAXABVCCalEntry@@AAV2@W4TCopyFields@1@@Z @ 21 NONAME ; void ESMRHelper::CopyFieldsL(class CCalEntry const &, class CCalEntry &, enum ESMRHelper::TCopyFields)
	?NewLC@CESMRFeatureSettings@@SAPAV1@XZ @ 22 NONAME ; class CESMRFeatureSettings * CESMRFeatureSettings::NewLC(void)
	?CorrespondingSmtpServiceL@ESMRHelper@@SAJJAAVCMsvSession@@@Z @ 23 NONAME ; long ESMRHelper::CorrespondingSmtpServiceL(long, class CMsvSession &)
	?CopyUserLC@ESMRHelper@@SAPAVCCalUser@@AAV2@@Z @ 24 NONAME ; class CCalUser * ESMRHelper::CopyUserLC(class CCalUser &)
	?CopyEntryLC@ESMRHelper@@SAPAVCCalEntry@@ABV2@W4TMethod@2@W4TCopyFields@1@W4TESMRCalendarEventType@@@Z @ 25 NONAME ; class CCalEntry * ESMRHelper::CopyEntryLC(class CCalEntry const &, enum CCalEntry::TMethod, enum ESMRHelper::TCopyFields, enum TESMRCalendarEventType)
	?GetCorrectDllDriveL@ESMRHelper@@SAXAAV?$TBuf@$0BAA@@@@Z @ 26 NONAME ; void ESMRHelper::GetCorrectDllDriveL(class TBuf<256> &)
	?SendingMailBoxL@ESMREntryHelper@@SAJABVTAgnEntryUiInParams@MAgnEntryUi@@AAVCMRMailboxUtils@@@Z @ 27 NONAME ; long ESMREntryHelper::SendingMailBoxL(class MAgnEntryUi::TAgnEntryUiInParams const &, class CMRMailboxUtils &)
	?NewL@CESMRFeatureSettings@@SAPAV1@XZ @ 28 NONAME ; class CESMRFeatureSettings * CESMRFeatureSettings::NewL(void)
	?IsRepeatingMeetingL@ESMREntryHelper@@SAHABVCCalEntry@@@Z @ 29 NONAME ; int ESMREntryHelper::IsRepeatingMeetingL(class CCalEntry const &)
	?CreateAndAppendOthersDirToFileName@ESMRHelper@@SAHAAV?$TBuf@$0BAA@@@@Z @ 30 NONAME ; int ESMRHelper::CreateAndAppendOthersDirToFileName(class TBuf<256> &)
	?IsAllDayEventL@ESMREntryHelper@@SAHABVCCalEntry@@@Z @ 31 NONAME ; int ESMREntryHelper::IsAllDayEventL(class CCalEntry const &)
	?KeyboardType@NMRGlobalFeatureSettings@@YA?AW4TKeyboardLayout@1@XZ @ 32 NONAME ; enum NMRGlobalFeatureSettings::TKeyboardLayout NMRGlobalFeatureSettings::KeyboardType(void)
	?Start@CMRActivityManager@@QAEXXZ @ 33 NONAME ; void CMRActivityManager::Start(void)
	?NewL@CMRActivityManager@@SAPAV1@AAVMMRActivityManagerObserver@@H@Z @ 34 NONAME ; class CMRActivityManager * CMRActivityManager::NewL(class MMRActivityManagerObserver &, int)
	?Reset@CMRActivityManager@@QAEXXZ @ 35 NONAME ; void CMRActivityManager::Reset(void)
	?SetTimeout@CMRActivityManager@@QAEXH@Z @ 36 NONAME ; void CMRActivityManager::SetTimeout(int)
	??1CMRActivityManager@@UAE@XZ @ 37 NONAME ; CMRActivityManager::~CMRActivityManager(void)

